@@ -5,6 +5,7 @@ from pyqtgraph.Qt import QtWidgets, QtGui
 import math
 from enum import Enum
 from .imageview2d import ImageView2D
+import multiprocessing as mp
 
 def symlog(data, C = 0):
     return np.sign(data) * np.log10( 1 + np.abs(data) / 10**C)
@@ -24,9 +25,16 @@ class Domain(Enum):
     FOURIER=1
 
 class NDSliceWindow(QtWidgets.QMainWindow):
+    # Styling constants
+    DIMENSION_LABEL_STYLE = "QLabel { font-size: 12px; padding: 1px; margin: 2px; }"
+    FLIP_ICON_STYLE = "QLabel { font-size: 20px; padding: 0px; margin: 0px; }"
+    BUTTON_STYLE = "QPushButton { font-size: 12px; padding: 2px; margin: 2px; }"
+    SPINBOX_STYLE = "QSpinBox { font-size: 12px; }"
+    RADIO_BUTTON_STYLE = "QRadioButton { font-size: 11px; }"
+    GROUPBOX_BASE_STYLE = "QGroupBox { font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }"
 
-    def __init__(self, data, *args, **kwargs):
-        super(NDSliceWindow, self).__init__(*args, **kwargs)
+    def __init__(self, data, complex_dim=None):
+        super(NDSliceWindow, self).__init__()
         self.resize(800,800)
 
         self.data = data
@@ -35,13 +43,27 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         self.channel = None
         self.scale = None
         
-        # Detect dark mode
-        self.is_dark_mode = self._detect_dark_mode()
+        self.axis_flipped = [False] * data.ndim  # Track flip state so that one can toggle dims and come back to the same flip state
+        
+        # If data is real-valued and has size-2 dimensions, ndslice can combine them as complex (ISMRMD uses this for real/imag parts)
+        if np.iscomplexobj(data):
+            self.can_combine_as_complex = [False] * data.ndim
+        else:
+            self.can_combine_as_complex = [data.shape[i] == 2 for i in range(data.ndim)]
+        self.combined_as_complex = [False] * data.ndim
+        
+        # Store complex_dim for later use (after widgets are created)
+        self._initial_complex_dim = complex_dim
+        
         for dim in range(0,data.ndim):
             if self.singleton[dim] is False and len(self.selected_indices) < 2:
                 self.selected_indices.append(dim)
-        if len(self.selected_indices) < 2:
+        # For 1D arrays, we only need one dimension; for 2D+, ensure we have two
+        if len(self.selected_indices) < 2 and data.ndim >= 2:
             self.selected_indices = [0, 1]
+        elif len(self.selected_indices) == 0:
+            # Edge case: if all dimensions are singleton, pick first one
+            self.selected_indices = [0]
         
         # Line plot mode uses a single selected dimension
         self.line_plot_dimension = 0  # Default to first non-singleton dimension
@@ -76,6 +98,8 @@ class NDSliceWindow(QtWidgets.QMainWindow):
             },
             'labels': {
                 'dims': [QtWidgets.QLabel('[' + str(data.shape[i]) + ']', alignment=Qt.QtCore.Qt.AlignCenter) for i in range(data.ndim)],
+                'flip': [QtWidgets.QLabel('', alignment=Qt.QtCore.Qt.AlignCenter) for i in range(data.ndim)],
+                'complex': [QtWidgets.QLabel('', alignment=Qt.QtCore.Qt.AlignCenter) for i in range(data.ndim)],
                 'primary': QtWidgets.QLabel('Y'),
                 'secondary': QtWidgets.QLabel('X'),
                 'slice': QtWidgets.QLabel('Slice'),
@@ -132,28 +156,33 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         
         for i, label in enumerate(self.widgets['labels']['dims']):
             label.mousePressEvent = lambda event, i=i, l=label: self.dimClicked(event, l, i)
-        self.widgets['labels']['primary'].mousePressEvent = self.transposeView
+            label.setCursor(QtGui.QCursor(Qt.QtCore.Qt.PointingHandCursor))
+            label.setToolTip(f"Apply centered FFT along dim {i}")
+
+        
+        # Set up flip labels with click handlers
+        for i, flip_label in enumerate(self.widgets['labels']['flip']):
+            flip_label.mousePressEvent = lambda event, i=i: self.flipAxisClicked(event, i)
+            flip_label.setStyleSheet(self.FLIP_ICON_STYLE)
+            flip_label.setAlignment(Qt.QtCore.Qt.AlignLeft | Qt.QtCore.Qt.AlignVCenter)
+        
+        # Set up complex indicator labels with click handlers
+        for i, complex_label in enumerate(self.widgets['labels']['complex']):
+            complex_label.mousePressEvent = lambda event, i=i: self.complexOrRealClicked(event, i)
+            complex_label.setStyleSheet(self.FLIP_ICON_STYLE)
+            complex_label.setAlignment(Qt.QtCore.Qt.AlignRight | Qt.QtCore.Qt.AlignVCenter)
         
         # Apply compact styling to dimension control widgets
-        self.widgets['labels']['dimensions'].setStyleSheet("QLabel { font-size: 11px; font-weight: bold; padding: 1px; margin: 2px; }")
-        self.widgets['labels']['dimensions'].setFixedHeight(18)  # Match the dimension labels height
-        self.widgets['labels']['primary'].setStyleSheet("QLabel { font-size: 11px; font-weight: bold; }")
-        self.widgets['labels']['secondary'].setStyleSheet("QLabel { font-size: 11px; font-weight: bold; }")
-        self.widgets['labels']['slice'].setStyleSheet("QLabel { font-size: 11px; font-weight: bold; }")
-        
-        # Make dimension labels much more compact
         for label in self.widgets['labels']['dims']:
-            label.setStyleSheet("QLabel { font-size: 11px; padding: 1px; margin: 2px; }")
-            label.setFixedHeight(18)  # Force a much smaller height
-            label.setMinimumWidth(30)  # Ensure minimum readability
+            label.setStyleSheet(self.DIMENSION_LABEL_STYLE)
+            label.setFixedHeight(24)
+            label.setMinimumWidth(30)
         
-        # Make dimension buttons more compact
         for btn in self.widgets['buttons']['primary'] + self.widgets['buttons']['secondary']:
-            btn.setStyleSheet("QPushButton { font-size: 11px; padding: 3px; margin: 2px; }")
+            btn.setStyleSheet(self.BUTTON_STYLE)
             
-        # Make spinboxes more compact
         for spin in self.widgets['spins']['slice_indices']:
-            spin.setStyleSheet("QSpinBox { font-size: 11px; }")
+            spin.setStyleSheet(self.SPINBOX_STYLE)
         
         # Set minimal spacing for all control layouts
         self.layouts['dims'].setSpacing(2)  # Extra tight for dimensions row
@@ -165,44 +194,67 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         self.layouts['slice'].setSpacing(2)  # Tighter spacing
         self.layouts['slice'].setContentsMargins(0, 1, 0, 1)  # Minimal margins
         
-        self.layouts['dims'].addWidget(self.widgets['labels']['dimensions'])
-        [self.layouts['dims'].addWidget(w) for w in self.widgets['labels']['dims']]
+        # For each dimension, create a QVBoxLayout with flip icon + dim label above primary button
+        dim_containers = []
+        for i in range(data.ndim):
+            # Create a container widget for this dimension column
+            container = QtWidgets.QWidget()
+            container_layout = QtWidgets.QVBoxLayout()
+            container_layout.setSpacing(0)
+            container_layout.setContentsMargins(0, 0, 0, 0)
+            
+            # Create horizontal layout for flip icon + dimension label
+            label_row = QtWidgets.QWidget()
+            label_layout = QtWidgets.QHBoxLayout()
+            label_layout.setSpacing(0)
+            label_layout.setContentsMargins(0, 0, 0, 0)
+            
+            # Add flip icon (left-aligned)
+            label_layout.addWidget(self.widgets['labels']['flip'][i])
+            # Add dimension label (centered, takes remaining space)
+            self.widgets['labels']['dims'][i].setAlignment(Qt.QtCore.Qt.AlignCenter)
+            label_layout.addWidget(self.widgets['labels']['dims'][i], 1)
+            # Add complex indicator (ℝ/ℂ)
+            label_layout.addWidget(self.widgets['labels']['complex'][i])
+            
+            label_row.setLayout(label_layout)
+            container_layout.addWidget(label_row)
+            
+            container.setLayout(container_layout)
+            dim_containers.append(container)
+            self.layouts['dims'].addWidget(container)
         
-        self.layouts['primary'].addWidget(self.widgets['labels']['primary'])
-        for i, w in enumerate(self.widgets['buttons']['primary']):
-            self.layouts['primary'].addWidget(w)
+        # Store containers for later access
+        self.dim_containers = dim_containers
+        
+        # Add all buttons and spinboxes to their vertical containers
+        for i in range(data.ndim):
+            w = self.widgets['buttons']['primary'][i]
+            self.dim_containers[i].layout().addWidget(w)
             w.clicked.connect(lambda checked, i=i : self.changedIndex(checked, 0, i))
-        
-        self.layouts['secondary'].addWidget(self.widgets['labels']['secondary'])
-        for i, w in enumerate(self.widgets['buttons']['secondary']):
-            self.layouts['secondary'].addWidget(w)
+            
+            w = self.widgets['buttons']['secondary'][i]
+            self.dim_containers[i].layout().addWidget(w)
             w.clicked.connect(lambda checked, i=i: self.changedIndex(checked, 1, i))
-
-        self.layouts['slice'].addWidget(self.widgets['labels']['slice'])
-        for i, w in enumerate(self.widgets['spins']['slice_indices']):
-            self.layouts['slice'].addWidget(w)
+            
+            w = self.widgets['spins']['slice_indices'][i]
+            self.dim_containers[i].layout().addWidget(w)
             w.valueChanged.connect(self.update)
         
         # Create a single compact control panel with all radio buttons
         controls_widget = QtWidgets.QWidget()
         controls_layout = QtWidgets.QVBoxLayout()
-        controls_layout.setSpacing(2)  # Reduce spacing between groups
-        controls_layout.setContentsMargins(5, 5, 5, 5)  # Reduce margins
         
         # Channel controls - horizontal layout to save space
         channel_group = QtWidgets.QGroupBox("Channel")
-        
-        if not self.is_dark_mode:
-            channel_group.setStyleSheet("QGroupBox { background-color: #F7FFE6; font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
-        else:
-            channel_group.setStyleSheet("QGroupBox { font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
+        channel_group.setStyleSheet(self.GROUPBOX_BASE_STYLE)
         channel_layout = QtWidgets.QHBoxLayout()
         channel_layout.setSpacing(5)
         channel_layout.setContentsMargins(3, 3, 3, 3)
         
         buttons = list(self.widgets['buttons']['channel'].values())
         for btn in buttons:
-            btn.setStyleSheet("QRadioButton { font-size: 11px; }")
+            btn.setStyleSheet(self.RADIO_BUTTON_STYLE)
             self.channel_button_group.addButton(btn)
             channel_layout.addWidget(btn)
             btn.clicked.connect(self.update)
@@ -212,17 +264,14 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         
         # Processing controls - horizontal layout
         processing_group = QtWidgets.QGroupBox("Scale")
-        if not self.is_dark_mode:
-            processing_group.setStyleSheet("QGroupBox { background-color: #F4E6FF; font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
-        else:
-            processing_group.setStyleSheet("QGroupBox { font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
+        processing_group.setStyleSheet(self.GROUPBOX_BASE_STYLE)
         processing_layout = QtWidgets.QHBoxLayout()
         processing_layout.setSpacing(5)
         processing_layout.setContentsMargins(3, 3, 3, 3)
         
         proc_buttons = list(self.widgets['buttons']['processing'].values())
         for btn in proc_buttons:
-            btn.setStyleSheet("QRadioButton { font-size: 11px; }")
+            btn.setStyleSheet(self.RADIO_BUTTON_STYLE)
             processing_layout.addWidget(btn)
             btn.clicked.connect(self.update)
         
@@ -231,17 +280,14 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         
         # Display controls - horizontal layout
         self.display_group = QtWidgets.QGroupBox("Display")
-        if not self.is_dark_mode:
-            self.display_group.setStyleSheet("QGroupBox { background-color: #e6f3ff; font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
-        else:
-            self.display_group.setStyleSheet("QGroupBox { font-size: 11px; font-weight: bold; padding-top: 8px; margin-top: 3px; } QGroupBox::title { subcontrol-origin: margin; left: 5px; }")
+        self.display_group.setStyleSheet(self.GROUPBOX_BASE_STYLE)
         display_layout = QtWidgets.QHBoxLayout()
         display_layout.setSpacing(5)
         display_layout.setContentsMargins(3, 3, 3, 3)
         
         disp_buttons = list(self.widgets['buttons']['display'].values())
         for btn in disp_buttons:
-            btn.setStyleSheet("QRadioButton { font-size: 11px; }")
+            btn.setStyleSheet(self.RADIO_BUTTON_STYLE)
             display_layout.addWidget(btn)
             btn.clicked.connect(self.update_display_mode)
         
@@ -378,6 +424,10 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         self.tab_widget.addTab(self.image_tab, "Image View")
         self.tab_widget.addTab(self.plot_tab, "Line Plot")
         
+        if data.ndim == 1:
+            self.tab_widget.setTabEnabled(0, False)  # Disable Image View tab
+            self.tab_widget.setCurrentIndex(1)  # Set line plot as default
+        
         # Connect tab change handler
         self.tab_widget.currentChanged.connect(self.on_tab_changed)
         
@@ -387,23 +437,25 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         self.layouts['topUp'].addWidget(self.widgets['labels']['pixelValue'])
         self.layouts['topUp'].addWidget(self.widgets['labels']['arrayInfo'])
 
-        # Make the left control panel much more compact with minimal spacing
-        self.layouts['botLeft'].setSpacing(1)  # Minimal spacing between rows
-        self.layouts['botLeft'].setContentsMargins(5, 2, 5, 2)  # Smaller top/bottom margins
-        
         self.layouts['botLeft'].addLayout(self.layouts['dims'])
-        self.layouts['botLeft'].addLayout(self.layouts['primary'])
-        self.layouts['botLeft'].addLayout(self.layouts['secondary'])
-        self.layouts['botLeft'].addLayout(self.layouts['slice'])
         
-        # Add stretch to prevent the control panel from expanding vertically
-        self.layouts['botLeft'].addStretch()
+        
+        # Create container widgets for proper alignment
+        left_container = QtWidgets.QWidget()
+        left_container.setLayout(self.layouts['botLeft'])
+        
+        right_container = QtWidgets.QWidget()
+        right_container.setLayout(self.layouts['botRight'])
+        
+        # Set both containers to expand vertically the same way
+        left_container.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
+        right_container.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
         
         self.layouts['top'].addLayout(self.layouts['topUp'],1)
         self.layouts['top'].addLayout(self.layouts['topDown'],20)  # Give viewport much more space
         
-        self.layouts['bot'].addLayout(self.layouts['botLeft'],12)
-        self.layouts['bot'].addLayout(self.layouts['botRight'],1)
+        self.layouts['bot'].addWidget(left_container, 12)
+        self.layouts['bot'].addWidget(right_container, 1)
 
         # Give the viewport (top) much more weight so it expands when window grows
         self.layouts['main'].addLayout(self.layouts['top'], 10)  # Viewport gets most space
@@ -412,19 +464,31 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         tmp.setLayout(self.layouts['main'])
         self.setCentralWidget(tmp)
         
-        self.changedIndex(True, 0, self.selected_indices[0], update=False)
-        self.changedIndex(True, 1, self.selected_indices[1], update=False)
+        # Initialize complex indicators for size-2 real dimensions
+        self.update_complex_indicators()
+        
+        if complex_dim is not None: # user requested combining as complex
+            if complex_dim < 0 or complex_dim >= data.ndim:
+                print(f"Warning: complex_dim={complex_dim} is out of range for {data.ndim}D array. Ignoring.")
+            elif np.iscomplexobj(data):
+                print(f"Warning: Data is already complex. Ignoring complex_dim={complex_dim}.")
+            elif data.shape[complex_dim] != 2:
+                print(f"Warning: Dimension {complex_dim} has shape {data.shape[complex_dim]}, not 2. Cannot combine as complex. Ignoring.")
+            else:
+                self.combineAsComplex(complex_dim) # valid
+        
+        # Initialize dimension controls based on data dimensions
+        if len(self.selected_indices) >= 1:
+            self.changedIndex(True, 0, self.selected_indices[0], update=False)
+        if len(self.selected_indices) >= 2:
+            self.changedIndex(True, 1, self.selected_indices[1], update=False)
         self.update_dimension_controls()  # Initialize dimension controls properly
         self.update()
         self.show()
-    
-    def _detect_dark_mode(self):
-        try:
-            palette = QtWidgets.QApplication.instance().palette()
-            bg_color = palette.color(QtGui.QPalette.Window)
-            return bg_color.lightness() < 128
-        except:
-            return False # assume light
+
+
+
+
     
     def dimClicked(self, event, label, dim):
         if self.singleton[dim]:
@@ -469,7 +533,189 @@ class NDSliceWindow(QtWidgets.QMainWindow):
     def _apply_ifft(self, dim):
         """Apply inverse FFT along specified dimension"""
         self.data = np.fft.ifftshift(np.fft.fft(np.fft.fftshift(self.data), axis=dim, norm='ortho'))
+    
+    def flipAxisClicked(self, event, dim):
+        """Handle click on flip axis icon"""
+        # Only respond if this dimension is currently selected
+        if dim not in self.selected_indices:
+            return
+        
+        # Toggle flip
+        self.axis_flipped[dim] = not self.axis_flipped[dim]
+        
+        self.update_flip_icons()
+        self.apply_axis_flips()
+        
+    def update_flip_icons(self):
+        for i, flip_label in enumerate(self.widgets['labels']['flip']):
+            if i in self.selected_indices:
+                # In line plot mode, only show horizontal flip icon for the plot dimension
+                if self.is_line_plot_mode():
+                    if i == self.line_plot_dimension:
+                        flip_label.setCursor(QtGui.QCursor(Qt.QtCore.Qt.SizeHorCursor))
+                        flip_label.setToolTip("Flip X axis")
+                        if self.axis_flipped[i]:
+                            flip_label.setText('⬅️')    
+                        else:
+                            flip_label.setText('➡️')
+                    else:
+                        flip_label.setText('')  # Hide flip icons for non-plot dimensions
+                        flip_label.setToolTip('')
+                # In image view mode, show vertical flip for primary, horizontal for secondary
+                elif i == self.selected_indices[0]:
+                    flip_label.setCursor(QtGui.QCursor(Qt.QtCore.Qt.SizeVerCursor))
+                    flip_label.setToolTip("Flip Y")
+                    if self.axis_flipped[i]:
+                        flip_label.setText('⬇️')
+                    else:
+                        flip_label.setText('⬆️')
+                elif len(self.selected_indices) > 1 and i == self.selected_indices[1]:
+                    flip_label.setCursor(QtGui.QCursor(Qt.QtCore.Qt.SizeHorCursor))
+                    flip_label.setToolTip("Flip X")
+                    if self.axis_flipped[i]:
+                        flip_label.setText('⬅️')
+                    else:
+                        flip_label.setText('➡️')
+                else:
+                    flip_label.setText('')  # Clear for dimensions not in primary/secondary
+                    flip_label.setToolTip('')
+            else:
+                flip_label.setText('')  # Clear for unselected dimensions
+                flip_label.setToolTip('')
+    
+    def apply_axis_flips(self):
+
+        
+        if self.is_line_plot_mode():
+            plot_view = self.plot_widget.getViewBox()
+            plot_dim = self.line_plot_dimension
+            plot_view.invertX(self.axis_flipped[plot_dim])
+        else:
+            if self.data.ndim == 1: # Shouldn't ever be in view mode for 1D data
+                return
             
+            view = self.img_view.getView()
+            
+            y_dim = self.selected_indices[0]
+            view.invertY(self.axis_flipped[y_dim])
+
+            if len(self.selected_indices) > 1:
+                x_dim = self.selected_indices[1]
+                view.invertX(self.axis_flipped[x_dim])
+
+    def update_complex_indicators(self):
+        """Initialize or update ℝ/ℂ indicators for dimensions that can be combined as complex"""
+        for i in range(self.data.ndim):
+            indicator = self.widgets['labels']['complex'][i]
+            
+            if self.combined_as_complex[i]:
+                indicator.setText('ℂ')
+                indicator.setStyleSheet(self.FLIP_ICON_STYLE + " QLabel {font-weight: bold; }")
+                indicator.setCursor(QtGui.QCursor(Qt.QtCore.Qt.PointingHandCursor))
+                indicator.setToolTip(f'Split to real')
+            elif self.can_combine_as_complex[i]:
+                indicator.setText('ℝ')
+                indicator.setStyleSheet(self.FLIP_ICON_STYLE + " QLabel {font-weight: bold; }")
+                indicator.setCursor(QtGui.QCursor(Qt.QtCore.Qt.PointingHandCursor))
+                indicator.setToolTip(f'Combine as complex')
+            else:
+                # No indicator, already-complex data or non-size-2 dimensions
+                indicator.setText('')
+                indicator.setToolTip('')
+                indicator.setCursor(QtGui.QCursor(Qt.QtCore.Qt.ArrowCursor))
+    
+    def complexOrRealClicked(self, event, dim):
+        if self.can_combine_as_complex[dim] and not self.combined_as_complex[dim]:
+            # ℝ clicked - combine to complex
+            self.combineAsComplex(dim)
+        elif self.combined_as_complex[dim]:
+            # ℂ clicked - split back to real
+            self.splitToReal(dim)
+    
+    def combineAsComplex(self, dim):
+        """Combine a size-2 real dimension into complex (real+imag), keeping singleton dimension (makes indexing easier)"""
+        if not self.can_combine_as_complex[dim] or self.combined_as_complex[dim]:
+            return
+        
+        # Build slices to extract real and imaginary parts
+        real_slice = [slice(None)] * self.data.ndim
+        imag_slice = [slice(None)] * self.data.ndim
+        real_slice[dim] = 0
+        imag_slice[dim] = 1
+        
+        self.data = np.expand_dims(self.data[tuple(real_slice)] + 1j * self.data[tuple(imag_slice)], axis=dim)
+
+        # Update state
+        self.combined_as_complex[dim] = True
+        self.can_combine_as_complex[dim] = False
+        self.singleton[dim] = True  # Now it's a singleton dimension
+        
+        # Once data is complex, no other dimension can be combined (all other size-2 dims become invalid)
+        for i in range(self.data.ndim):
+            if i != dim:
+                self.can_combine_as_complex[i] = False
+        
+        # If the converted dimension was in selected_indices or line_plot_dimension, we need to find a new valid selection
+        if dim in self.selected_indices:
+            # Find a new non-singleton dimension to replace it
+            for new_dim in range(self.data.ndim):
+                if not self.singleton[new_dim] and new_dim not in self.selected_indices:
+                    idx = self.selected_indices.index(dim)
+                    self.selected_indices[idx] = new_dim
+                    break
+        
+        # Same problem can happen with line plot.
+        if self.line_plot_dimension == dim:
+            for new_dim in range(self.data.ndim):
+                if not self.singleton[new_dim]:
+                    self.line_plot_dimension = new_dim
+                    break
+        
+        # Enable complex channel buttons now that data is complex
+        for button in self.widgets['buttons']['channel'].values():
+            button.setEnabled(True)
+        
+        if not self.widgets['buttons']['channel']['abs'].isChecked():
+            self.widgets['buttons']['channel']['abs'].setChecked(True)
+        
+        # Update UI
+        self.update_complex_indicators()
+        self.update_dimension_controls()
+        self.update()
+    
+    def splitToReal(self, dim):
+        """Split a complex dimension back to real (real+imag as separate slices)"""
+        if not self.combined_as_complex[dim]:
+            return
+        
+        # Restore data to real with size-2 dimension
+        self.data = np.stack([np.real(self.data).squeeze(dim), 
+                              np.imag(self.data).squeeze(dim)], axis=dim)
+        
+        # Update state
+        self.combined_as_complex[dim] = False
+        self.can_combine_as_complex[dim] = True
+        self.singleton[dim] = False
+        
+        # Data is now real - re-enable combining for all size-2 dimensions
+        for i in range(self.data.ndim):
+            if self.data.shape[i] == 2:
+                self.can_combine_as_complex[i] = True
+        
+        # Update max value for the spinbox for this dimension
+        self.widgets['spins']['slice_indices'][dim].setMaximum(self.data.shape[dim] - 1)
+        
+        # Disable complex channel buttons (data is now real)
+        for button in self.widgets['buttons']['channel'].values():
+            button.setEnabled(False)
+        
+        # Switch to 'real' channel
+        self.widgets['buttons']['channel']['real'].setChecked(True)
+        
+        # Update UI
+        self.update_complex_indicators()
+        self.update_dimension_controls()
+        self.update()
     
     def getPixel(self, pos):
         img = self.img_view.image
@@ -487,6 +733,9 @@ class NDSliceWindow(QtWidgets.QMainWindow):
 
     
     def update_image_view(self):
+        if self.data.ndim == 1: # No image view for 1D data
+            return
+            
         prev_levels = None
         al = True
         def_levels = None
@@ -547,6 +796,9 @@ class NDSliceWindow(QtWidgets.QMainWindow):
             image_data = np.nan_to_num(np.squeeze(image_data))
             self.img_view.setImage(image_data, autoLevels=al, levels=prev_levels)
             
+            # Apply axis flips after setting the image
+            self.apply_axis_flips()
+            
         except Exception as e:
             print(f'Image update failed: {e}')
     
@@ -575,22 +827,22 @@ class NDSliceWindow(QtWidgets.QMainWindow):
             return
         
         if mode == 'fit': #use the viewport aspect ratio
+            aspect_str = ''
             try:
-                view = self.img_view.getView()
-                view_rect = view.viewRect()
-                if view_rect.width() > 0 and view_rect.height() > 0:
-                    # Get the actual widget size to calculate viewport aspect ratio
-                    widget_size = view.size()
-                    viewport_ratio = widget_size.width() / widget_size.height()
-                    if abs(viewport_ratio - 1.0) < 1e-2:
+                if hasattr(self.img_view, 'image') and self.img_view.image is not None:
+                    view = self.img_view.getView()
+                    
+                    img_height, img_width = self.img_view.image.shape
+                    widget_ratio = view.size().width() / view.size().height()
+                    img_ratio = img_width / img_height
+                    ratio = img_ratio * widget_ratio
+                    
+                    if abs(ratio - 1.0) < 1e-2:
                         aspect_str = '(1:1)'
                     else:
-                        aspect_str = f'({viewport_ratio:.2f}:1)'
-                else:
-                    aspect_str = ''
-            except:
-                aspect_str = ''
-            self.display_group.setTitle(f'Display {aspect_str}')
+                        aspect_str = f'({ratio:.2f}:1)'
+            finally:
+                self.display_group.setTitle(f'Display {aspect_str}')
             
         elif mode == 'square_fov':
             # For square FOV, use the image aspect ratio
@@ -760,10 +1012,15 @@ class NDSliceWindow(QtWidgets.QMainWindow):
     def is_line_plot_mode(self):
         """Check if currently in line plot mode"""
         return self.tab_widget.currentIndex() == 1
-    
+
     def transposeView(self, event):
         old_primary = self.selected_indices[0]
-        self.changedIndex(event, 0, self.selected_indices[1], update=False)
+        old_secondary = self.selected_indices[1]
+
+        # Swap the flip states along with the dimensions (prevents the axes from appearing flipped after transpose)
+        self.axis_flipped[old_primary], self.axis_flipped[old_secondary] = self.axis_flipped[old_secondary], self.axis_flipped[old_primary]
+        
+        self.changedIndex(event, 0, old_secondary, update=False)
         self.changedIndex(event, 1, old_primary, update=True)
 
     def update(self):
@@ -788,7 +1045,9 @@ class NDSliceWindow(QtWidgets.QMainWindow):
                 self.line_plot_dimension = idx
         else:
             # In image view mode, use the original two-dimension selection
-            self.selected_indices[which_one] = idx
+            # For 1D arrays, we don't have a second dimension
+            if which_one < len(self.selected_indices):
+                self.selected_indices[which_one] = idx
         
         self.update_dimension_controls()
         if update is True:
@@ -848,14 +1107,26 @@ class NDSliceWindow(QtWidgets.QMainWindow):
                     bPrim.setChecked(False)
                     bSecondary.setChecked(False)
                     
-            self.widgets['buttons']['primary'][self.selected_indices[0]].setChecked(True)
-            self.widgets['buttons']['secondary'][self.selected_indices[1]].setChecked(True)
+            # Only set buttons if we have at least 2 selected indices
+            if len(self.selected_indices) >= 1:
+                self.widgets['buttons']['primary'][self.selected_indices[0]].setChecked(True)
+            if len(self.selected_indices) >= 2:
+                self.widgets['buttons']['secondary'][self.selected_indices[1]].setChecked(True)
+        
+        self.update_flip_icons()
     
     def keyPressEvent(self, event):
         """Handle keyboard shortcuts"""
         key = event.key()
         modifiers = event.modifiers()
         
+        # Check for 'T' key to transpose view (swap X and Y dimensions)
+        if key == Qt.QtCore.Qt.Key.Key_T and modifiers == Qt.QtCore.Qt.KeyboardModifier.NoModifier:
+            if not self.is_line_plot_mode() and len(self.selected_indices) >= 2:
+                self.transposeView(event)
+                event.accept()
+                return
+        
         # Check CTRL+number for colormap changes
         if modifiers == Qt.QtCore.Qt.KeyboardModifier.ControlModifier:
             if key == Qt.QtCore.Qt.Key.Key_1:
@@ -901,17 +1172,24 @@ class NDSliceWindow(QtWidgets.QMainWindow):
         except Exception as e:
             print(f"Failed to set colormap {colormap_name}: {e}")
         
-def ndslice(data, title=''):
+def _run_window(data, title, complex_dim=None):
+    """Opens a window in a separate process which is blocked on exec()"""
+    app = QtWidgets.QApplication.instance()
+    if app is None:
+        app = QtWidgets.QApplication([])
+    win = NDSliceWindow(data, complex_dim=complex_dim)
+    win.setWindowTitle(title)
+    win.show()
+    app.exec()
+
+def ndslice(data, title='', block=False, complex_dim=None):
     if not isinstance(data, np.ndarray):
         raise TypeError("data must be a numpy array")
     if data.ndim < 1:
         raise ValueError("data must have at least 1 dimension")
     
-    app = QtWidgets.QApplication.instance()
-    if app is None:
-        app = QtWidgets.QApplication([])
-    win = NDSliceWindow(data)
-    win.setWindowTitle(title)
-    win.show()
-    app.exec()
+    if block:
+        _run_window(data, title, complex_dim)
+    else:
+        process = mp.Process(target=_run_window, args=(data, title, complex_dim)).start()
     
\ No newline at end of file
